@@ -1,21 +1,8 @@
-// GUI of MediaInfo
-// Copyright (C) 2011-2012 MediaArea.net SARL, Info@MediaArea.net
-//
-// This program is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Library General Public License as published by
-// the Free Software Foundation, either version 2 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public License
-// along with this program. If not, see <http://www.gnu.org/licenses/>.
-//
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+/*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ *
+ *  Use of this source code is governed by a BSD-style license that can
+ *  be found in the License.html file in the root of the source tree.
+ */
 
 #include "mainwindow.h"
 #include "translate.h"
@@ -160,7 +147,7 @@ bool MainWindow::isNewer(QString distant, QString local) {
 
 void MainWindow::checkForNewVersion() {
     QString version = VERSION;
-    QUrl url = QUrl("http://mediaarea.net/mediainfo_check/changelog_"+version+".bin");
+    QUrl url = QUrl("http://MediaArea.net/MediaInfo_check/changelog_"+version+".bin");
     file = "";
     reply = qnam.get(QNetworkRequest(url));
     qDebug() << "downloading " << url.toString();
@@ -270,7 +257,7 @@ QDir MainWindow::getCommonDir(Core*C) {
     QList<QStringList> list;
     QStringList dirName;
     unsigned fileCount = (unsigned)C->Count_Get();
-    if(fileCount<=0)
+    if(fileCount==0)
         return QDir::home();
     for(unsigned filePos=0;filePos<fileCount;filePos++)
         list.append(QDir::toNativeSeparators(wstring2QString(C->Get(filePos,Stream_General, 0, __T("CompleteName")))).split(QDir::separator ()));
