@@ -1,21 +1,8 @@
-// GUI_Export - Export interface of MediaInfo
-// Copyright (C) 2002-2012 MediaArea.net SARL, Info@MediaArea.net
-//
-// This program is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Library General Public License as published by
-// the Free Software Foundation, either version 2 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public License
-// along with this program. If not, see <http://www.gnu.org/licenses/>.
-//
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+/*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ *
+ *  Use of this source code is governed by a BSD-style license that can
+ *  be found in the License.html file in the root of the source tree.
+ */
 
 //---------------------------------------------------------------------------
 // Compilation condition
@@ -108,6 +95,12 @@ void TExportF::Name_Adapt()
         SaveDialog1->DefaultExt=__T("xml");
         SaveDialog1->Filter=__T("XML File|*.xml");
     }
+    else if (Export->ActivePage==Export_EBUCore_1_4)
+    {
+        FN.Extension_Set(__T("xml"));
+        SaveDialog1->DefaultExt=__T("xml");
+        SaveDialog1->Filter=__T("XML File|*.xml");
+    }
     else if (Export->ActivePage==Export_reVTMD)
     {
         FN.Extension_Set(__T("xml"));
@@ -152,6 +145,8 @@ int TExportF::Run(MediaInfoNameSpace::MediaInfoList &MI, ZenLib::Ztring DefaultF
         Export->ActivePage=Export_MPEG7;
     else if (Info==__T("PBCore_1.2"))
         Export->ActivePage=Export_PBCore;
+    else if (Info==__T("EBUCore_1.4"))
+        Export->ActivePage=Export_EBUCore_1_4;
     else if (Info==__T("reVTMD"))
         Export->ActivePage=Export_reVTMD;
 
@@ -254,14 +249,14 @@ void TExportF::Export_Run()
         //Chapters
         Pos_Start=Pos_End+2;
         Pos_End=Parameters.size()-1;
-        for (int Count=0; Count<CSV_Stream_Chapters->ItemIndex; Count++)
+        for (int Count=0; Count<CSV_Stream_Other->ItemIndex; Count++)
         {
             for (int I1=0; I1<Pos_End-Pos_Start; I1++)
-            if (MediaInfo_Complete || ToExport->Get(0, Stream_Chapters, 0, I1, Info_Options)[InfoOption_ShowInInform]==__T('Y'))
+            if (MediaInfo_Complete || ToExport->Get(0, Stream_Other, 0, I1, Info_Options)[InfoOption_ShowInInform]==__T('Y'))
                 {
                     CSV(0, CSV_Pos)=Ztring(__T("Chapters "))+Ztring::ToZtring(Count)+__T(" ")+Parameters(Pos_Start+I1, 0);
                     for (int FilePos=0; FilePos<ToExport->Count_Get(); FilePos++)
-                        CSV(1+FilePos, CSV_Pos)=ToExport->Get(FilePos, Stream_Chapters, Count, I1);
+                        CSV(1+FilePos, CSV_Pos)=ToExport->Get(FilePos, Stream_Other, Count, I1);
                     CSV_Pos++;
                 }
         }
@@ -308,7 +303,7 @@ void TExportF::Export_Run()
               case __T('V'): S=Stream_Video; break;
               case __T('A'): S=Stream_Audio; break;
               case __T('T'): S=Stream_Text; break;
-              case __T('C'): S=Stream_Chapters; break;
+              case __T('C'): S=Stream_Other; break;
               default: S=Stream_General;
             }
             SheetF(0, Pos)=ToExport->Get(0, S, Prefs->Details[Prefs_Sheet](Z1, 2).To_int32u(), Prefs->Details[Prefs_Sheet](Z1, 3), Info_Name_Text);
@@ -332,7 +327,7 @@ void TExportF::Export_Run()
                   case __T('V'): S=Stream_Video; break;
                   case __T('A'): S=Stream_Audio; break;
                   case __T('T'): S=Stream_Text; break;
-                  case __T('C'): S=Stream_Chapters; break;
+                  case __T('C'): S=Stream_Other; break;
                   default: S=Stream_General;
                 }
                 //Showing
@@ -425,6 +420,22 @@ void TExportF::Export_Run()
         }
         Text=ToExport->Inform().c_str();
     }
+    else if (Export->ActivePage==Export_EBUCore_1_4)
+    {
+        ToExport->Option_Static(__T("Inform"), __T("EBUCore_1.4"));
+        if (Export_EBUCore_1_4_SideCar->Checked)
+        {
+            for (size_t Pos=0; Pos<ToExport->Count_Get(); Pos++)
+            {
+                Text=ToExport->Inform(Pos).c_str();
+                File F;
+                F.Create(Ztring(ToExport->Get(Pos, Stream_General, 0, __T("CompleteName")).c_str())+__T(".EBUCore.xml"));
+                F.Write(Text);
+            }
+            return;
+        }
+        Text=ToExport->Inform().c_str();
+    }
     else if (Export->ActivePage==Export_reVTMD)
     {
         ToExport->Option_Static(__T("Inform"), __T("reVTMD"));
@@ -502,6 +513,13 @@ void __fastcall TExportF::ExportChange(TObject *Sender)
         File_Append->Visible=false;
         Name_Choose->Visible=Export_PBCore_SideCar->Checked?false:true;;
     }
+    else if (Export->ActivePage==Export_EBUCore_1_4)
+    {
+        Export_EBUCore_1_4_SideCarClick(Sender);
+        File_Append->Checked=false;
+        File_Append->Visible=false;
+        Name_Choose->Visible=Export_EBUCore_1_4_SideCar->Checked?false:true;;
+    }
     else if (Export->ActivePage==Export_reVTMD)
     {
         Export_reVTMD_SideCarClick(Sender);
@@ -555,9 +573,9 @@ void __fastcall TExportF::CSV_Stream_TextChange(TObject *Sender)
 }
 //---------------------------------------------------------------------------
 
-void __fastcall TExportF::CSV_Stream_ChaptersChange(TObject *Sender)
+void __fastcall TExportF::CSV_Stream_OtherChange(TObject *Sender)
 {
-    CSV_Stream_Change(CSV_Stream_Chapters, CSV_Stream_Chapters_Warning, Stream_Chapters);
+    CSV_Stream_Change(CSV_Stream_Other, CSV_Stream_Other_Warning, Stream_Other);
 }
 //---------------------------------------------------------------------------
 
@@ -579,6 +597,11 @@ void __fastcall TExportF::Export_PBCore_SideCarClick(TObject *Sender)
 }
 //---------------------------------------------------------------------------
 
+void __fastcall TExportF::Export_EBUCore_1_4_SideCarClick(TObject *Sender)
+{
+    Name_Choose->Visible=Export_EBUCore_1_4_SideCar->Checked?false:true;
+}
+//---------------------------------------------------------------------------
 void __fastcall TExportF::Export_reVTMD_SideCarClick(TObject *Sender)
 {
     Name_Choose->Visible=Export_reVTMD_SideCar->Checked?false:true;
@@ -596,8 +619,8 @@ void TExportF::GUI_Configure()
     CSV_Stream_Audio_Warning->Caption=Prefs->Translate(__T("Warning : more streams in the files")).c_str();
     CSV_Stream_Text_Caption->Caption=Prefs->Translate(__T("How many text streams?")).c_str();
     CSV_Stream_Text_Warning->Caption=Prefs->Translate(__T("Warning : more streams in the files")).c_str();
-    CSV_Stream_Chapters_Caption->Caption=Prefs->Translate(__T("How many chapters streams?")).c_str();
-    CSV_Stream_Chapters_Warning->Caption=Prefs->Translate(__T("Warning : more streams in the files")).c_str();
+    CSV_Stream_Other_Caption->Caption=Prefs->Translate(__T("How many chapters streams?")).c_str();
+    CSV_Stream_Other_Warning->Caption=Prefs->Translate(__T("Warning : more streams in the files")).c_str();
     CSV_Separator_Col_Caption->Caption=Prefs->Translate(__T("Separator_Columns")).c_str();
     CSV_Decimal_Caption->Caption=Prefs->Translate(__T("Decimal point")).c_str();
     CSV_Separator_Line_Caption->Caption=Prefs->Translate(__T("Separator_Lines")).c_str();
@@ -622,7 +645,7 @@ void TExportF::GUI_Configure()
     CSV_Stream_Change(CSV_Stream_Video, CSV_Stream_Video_Warning, Stream_Video);
     CSV_Stream_Change(CSV_Stream_Audio, CSV_Stream_Audio_Warning, Stream_Audio);
     CSV_Stream_Change(CSV_Stream_Text, CSV_Stream_Text_Warning, Stream_Text);
-    CSV_Stream_Change(CSV_Stream_Chapters, CSV_Stream_Chapters_Warning, Stream_Chapters);
+    CSV_Stream_Change(CSV_Stream_Other, CSV_Stream_Other_Warning, Stream_Other);
 }
 
 //***************************************************************************
@@ -631,4 +654,3 @@ void TExportF::GUI_Configure()
 
 #endif //MEDIAINFOGUI_EXPORT_NO
 
-
