@@ -1,21 +1,8 @@
-// GUI_Main - Main interface of MediaInfo
-// Copyright (C) 2002-2012 MediaArea.net SARL, Info@MediaArea.net
-//
-// This program is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Library General Public License as published by
-// the Free Software Foundation, either version 2 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public License
-// along with this program. If not, see <http://www.gnu.org/licenses/>.
-//
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+/*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ *
+ *  Use of this source code is governed by a BSD-style license that can
+ *  be found in the License.html file in the root of the source tree.
+ */
 
 //---------------------------------------------------------------------------
 #include <vcl.h>
@@ -91,7 +78,7 @@ TCustomButton*              Donate_Current;
 //---------------------------------------------------------------------------
 
 //---------------------------------------------------------------------------
-const ZenLib::Char* MEDIAINFO_TITLE=__T("MediaInfo - http:\/\/mediainfo.sourceforge.net");
+const ZenLib::Char* MEDIAINFO_TITLE=__T("MediaArea.net/MediaInfo");
 const size_t Title_Pos=96; //TODO: Position of Title in General.csv, should shange this...
 MediaInfoList *I;
 //---------------------------------------------------------------------------
@@ -138,7 +125,7 @@ __fastcall TMainF::TMainF(TComponent* Owner)
     Page_Easy_X_List [Stream_Video]     =Page_Easy_General_List_V;
     Page_Easy_X_List [Stream_Audio]     =Page_Easy_General_List_A;
     Page_Easy_X_List [Stream_Text]      =Page_Easy_General_List_T;
-    Page_Easy_X_List [Stream_Chapters]  =Page_Easy_General_List_C;
+    Page_Easy_X_List [Stream_Other]  =Page_Easy_General_List_C;
     Page_Easy_X_Tag[0]=Page_Easy_General_Tag1;
     Page_Easy_X_Tag[1]=Page_Easy_General_Tag2;
     Page_Easy_X_Tag[2]=Page_Easy_General_Tag3;
@@ -149,12 +136,12 @@ __fastcall TMainF::TMainF(TComponent* Owner)
     Page_Sheet_X[Stream_Video]=Page_Sheet_V;
     Page_Sheet_X[Stream_Audio]=Page_Sheet_A;
     Page_Sheet_X[Stream_Text]=Page_Sheet_T;
-    Page_Sheet_X[Stream_Chapters]=Page_Sheet_C;
+    Page_Sheet_X[Stream_Other]=Page_Sheet_C;
     Page_Sheet_X_Web[Stream_General]=Page_Sheet_G_Web;
     Page_Sheet_X_Web[Stream_Video]=Page_Sheet_V_Web;
     Page_Sheet_X_Web[Stream_Audio]=Page_Sheet_A_Web;
     Page_Sheet_X_Web[Stream_Text]=Page_Sheet_T_Web;
-    Page_Sheet_X_Web[Stream_Chapters]=Page_Sheet_C_Web;
+    Page_Sheet_X_Web[Stream_Other]=Page_Sheet_C_Web;
     //-Donate
     Donates.push_back(Donate_de);
     Donates.push_back(Donate_en);
@@ -184,8 +171,16 @@ __fastcall TMainF::TMainF(TComponent* Owner)
 void __fastcall TMainF::GUI_Configure()
 {
     //Hard coded
-    Width=700;
-    Height=392;
+    Width=500;
+    Height=400;
+    if (Screen->Width>=1024)
+        Width=700;
+    if (Screen->Width>=1280)
+        Width=820;
+    if (Screen->Height>=768)
+        Height=500;
+    if (Screen->Height>=1024)
+        Height=600;
     Left=(Screen->Width-Width)/2;
     Top=(Screen->Height-Height)/2;
 
@@ -219,6 +214,7 @@ void __fastcall TMainF::GUI_Configure()
     else if (Prefs->Config(__T("Output"))==__T("XML")) {M_View_XMLClick(NULL); M_View_XML->Checked=true;}
     else if (Prefs->Config(__T("Output"))==__T("MPEG-7")) {M_View_MPEG7Click(NULL); M_View_MPEG7->Checked=true;}
     else if (Prefs->Config(__T("Output"))==__T("PBCore_1.2")) {M_View_PBCoreClick(NULL); M_View_PBCore->Checked=true;}
+    else if (Prefs->Config(__T("Output"))==__T("EBUCore_1.4")) {M_View_PBCoreClick(NULL); M_View_EBUCore_1_4->Checked=true;}
     else if (Prefs->Config(__T("Output"))==__T("reVTMD")) {M_View_reVTMDClick(NULL); M_View_reVTMD->Checked=true;}
     else if (Prefs->Config(__T("Output"))==__T("Custom")) {M_View_CustomClick(NULL); M_View_Custom->Checked=true;}
 
@@ -636,7 +632,7 @@ void __fastcall TMainF::Refresh(TTabSheet *Page)
                   case __T('V'): S=Stream_Video; break;
                   case __T('A'): S=Stream_Audio; break;
                   case __T('T'): S=Stream_Text; break;
-                  case __T('C'): S=Stream_Chapters; break;
+                  case __T('C'): S=Stream_Other; break;
                   default: S=Stream_General;
                 }
                 Page_Sheet_Sheet->Cells[Pos][0]=I->Get(0, S, Prefs->Details[Prefs_Sheet](Z1, 2).To_int32u(), Prefs->Details[Prefs_Sheet](Z1, 3), Info_Name_Text).c_str();
@@ -660,7 +656,7 @@ void __fastcall TMainF::Refresh(TTabSheet *Page)
                       case __T('V'): S=Stream_Video; break;
                       case __T('A'): S=Stream_Audio; break;
                       case __T('T'): S=Stream_Text; break;
-                      case __T('C'): S=Stream_Chapters; break;
+                      case __T('C'): S=Stream_Other; break;
                       default: S=Stream_General;
                     }
                     //Showing
@@ -794,6 +790,8 @@ void __fastcall TMainF::Refresh(TTabSheet *Page)
             I->Option_Static(__T("Inform"), __T("MPEG-7"));
         else if (M_View_PBCore->Checked)
             I->Option_Static(__T("Inform"), __T("PBCore_1.2"));
+        else if (M_View_EBUCore_1_4->Checked)
+            I->Option_Static(__T("Inform"), __T("EBUCore_1.4"));
         else if (M_View_reVTMD->Checked)
             I->Option_Static(__T("Inform"), __T("reVTMD"));
         else
@@ -888,10 +886,10 @@ void __fastcall TMainF::Refresh(TTabSheet *Page)
     }
     else if (FilesCount==1)
         //un fichier
-        Caption=(Title+__T(" - ")+I->Get(0, Stream_General, 0, __T("CompleteName"))).c_str();
+        Caption=(Ztring(MEDIAINFO_TITLE)+__T(" - ")+I->Get(0, Stream_General, 0, __T("CompleteName"))).c_str();
     else
         //Plusieurs selections
-        Caption=(Title+__T(" - ")+Ztring::ToZtring(FilesCount)+Prefs->Translate(__T(" file2"))).c_str();
+        Caption=(Ztring(MEDIAINFO_TITLE)+__T(" - ")+Ztring::ToZtring(FilesCount)+Prefs->Translate(__T(" file2"))).c_str();
 
     //Configure Default options
     if (FilesCount>0)
@@ -1102,6 +1100,14 @@ void __fastcall TMainF::M_View_PBCoreClick(TObject *Sender)
     ChangePage(Page_Custom);
 }
 
+//---------------------------------------------------------------------------
+void __fastcall TMainF::M_View_EBUCore_1_4Click(TObject *Sender)
+{
+    Prefs->Details[Prefs_Custom].Write(__T("EBUCore_1.4"));
+    ToolBar_View_EBUCore_1_4->Checked=true;
+    ChangePage(Page_Custom);
+}
+
 //---------------------------------------------------------------------------
 void __fastcall TMainF::M_View_CustomClick(TObject *Sender)
 {
@@ -1569,67 +1575,67 @@ MESSAGE void __fastcall TMainF::HandleDropFiles (TMessage& Msg)
 //---------------------------------------------------------------------------
 void __fastcall TMainF::Donate_deClick(TObject *Sender)
 {
-    ShellExecute(NULL, NULL, __T("http://mediainfo.sourceforge.net/de/Donate"), NULL, NULL, SW_SHOWNORMAL);
+    ShellExecute(NULL, NULL, __T("http://MediaArea.net/MediaInfo/de/Donate"), NULL, NULL, SW_SHOWNORMAL);
 }
 
 //---------------------------------------------------------------------------
 void __fastcall TMainF::Donate_enClick(TObject *Sender)
 {
-    ShellExecute(NULL, NULL, __T("http://mediainfo.sourceforge.net/en/Donate"), NULL, NULL, SW_SHOWNORMAL);
+    ShellExecute(NULL, NULL, __T("http://MediaArea.net/MediaInfo/en/Donate"), NULL, NULL, SW_SHOWNORMAL);
 }
 
 //---------------------------------------------------------------------------
 void __fastcall TMainF::Donate_esClick(TObject *Sender)
 {
-    ShellExecute(NULL, NULL, __T("http://mediainfo.sourceforge.net/es/Donate"), NULL, NULL, SW_SHOWNORMAL);
+    ShellExecute(NULL, NULL, __T("http://MediaArea.net/MediaInfo/es/Donate"), NULL, NULL, SW_SHOWNORMAL);
 }
 
 //---------------------------------------------------------------------------
 void __fastcall TMainF::Donate_frClick(TObject *Sender)
 {
-    ShellExecute(NULL, NULL, __T("http://mediainfo.sourceforge.net/fr/Donate"), NULL, NULL, SW_SHOWNORMAL);
+    ShellExecute(NULL, NULL, __T("http://MediaArea.net/MediaInfo/fr/Donate"), NULL, NULL, SW_SHOWNORMAL);
 }
 
 //---------------------------------------------------------------------------
 void __fastcall TMainF::Donate_itClick(TObject *Sender)
 {
-    ShellExecute(NULL, NULL, __T("http://mediainfo.sourceforge.net/it/Donate"), NULL, NULL, SW_SHOWNORMAL);
+    ShellExecute(NULL, NULL, __T("http://MediaArea.net/MediaInfo/it/Donate"), NULL, NULL, SW_SHOWNORMAL);
 }
 
 //---------------------------------------------------------------------------
 void __fastcall TMainF::Donate_jaClick(TObject *Sender)
 {
-    ShellExecute(NULL, NULL, __T("http://mediainfo.sourceforge.net/ja/Donate"), NULL, NULL, SW_SHOWNORMAL);
+    ShellExecute(NULL, NULL, __T("http://MediaArea.net/MediaInfo/ja/Donate"), NULL, NULL, SW_SHOWNORMAL);
 }
 
 //---------------------------------------------------------------------------
 void __fastcall TMainF::Donate_plClick(TObject *Sender)
 {
-    ShellExecute(NULL, NULL, __T("http://mediainfo.sourceforge.net/pl/Donate"), NULL, NULL, SW_SHOWNORMAL);
+    ShellExecute(NULL, NULL, __T("http://MediaArea.net/MediaInfo/pl/Donate"), NULL, NULL, SW_SHOWNORMAL);
 }
 
 //---------------------------------------------------------------------------
 void __fastcall TMainF::Donate_zh_CNClick(TObject *Sender)
 {
-    ShellExecute(NULL, NULL, __T("http://mediainfo.sourceforge.net/zh_CN/Donate"), NULL, NULL, SW_SHOWNORMAL);
+    ShellExecute(NULL, NULL, __T("http://MediaArea.net/MediaInfo/zh_CN/Donate"), NULL, NULL, SW_SHOWNORMAL);
 }
 
 //---------------------------------------------------------------------------
 void __fastcall TMainF::Donate_zh_TWClick(TObject *Sender)
 {
-    ShellExecute(NULL, NULL, __T("http://mediainfo.sourceforge.net/zh_TW/Donate"), NULL, NULL, SW_SHOWNORMAL);
+    ShellExecute(NULL, NULL, __T("http://MediaArea.net/MediaInfo/zh_TW/Donate"), NULL, NULL, SW_SHOWNORMAL);
 }
 
 //---------------------------------------------------------------------------
 void __fastcall TMainF::Donate___Click(TObject *Sender)
 {
-    ShellExecute(NULL, NULL, (Ztring(__T("http://mediainfo.sourceforge.net/"))+Prefs->Translate(__T("  Language_ISO639"))+__T("/Donate")).c_str(), NULL, NULL, SW_SHOWNORMAL);
+    ShellExecute(NULL, NULL, (Ztring(__T("http://mediaarea.net/"))+Prefs->Translate(__T("  Language_ISO639"))+__T("MediaInfo/Donate")).c_str(), NULL, NULL, SW_SHOWNORMAL);
 }
 
 //---------------------------------------------------------------------------
 void __fastcall TMainF::M_NewVersionClick(TObject *Sender)
 {
-    ShellExecute(NULL, NULL, (Ztring(__T("http://mediainfo.sourceforge.net/"))+Prefs->Translate(__T("  Language_ISO639"))+__T("?NewVersionRequested=true")).c_str(), NULL, NULL, SW_SHOWNORMAL);
+    ShellExecute(NULL, NULL, (Ztring(__T("http://mediaarea.net/"))+Prefs->Translate(__T("  Language_ISO639"))+__T("/MediaInfo/?NewVersionRequested=true")).c_str(), NULL, NULL, SW_SHOWNORMAL);
 }
 
 void __fastcall TMainF::M_DigimetricsClick(TObject *Sender)
