@@ -182,12 +182,14 @@ __published:    // IDE-managed Components
     TMenuItem *M_View_XML;
     TMenuItem *M_View_MPEG7;
     TMenuItem *M_View_PBCore;
+    TMenuItem *M_View_EBUCore_1_4;
     TMenuItem *M_Digimetrics;
     TToolButton *Tool_Digimetrics;
     TMenuItem *M_View_reVTMD;
     TMenuItem *ToolBar_View_XML;
     TMenuItem *ToolBar_View_MPEG7;
     TMenuItem *ToolBar_View_PBCore;
+    TMenuItem *ToolBar_View_EBUCore_1_4;
     TMenuItem *ToolBar_View_reVTMD;
     void __fastcall FormResize(TObject *Sender);
     void __fastcall M_Help_AboutClick(TObject *Sender);
@@ -244,6 +246,7 @@ __published:    // IDE-managed Components
     void __fastcall M_NewVersionClick(TObject *Sender);
     void __fastcall M_View_MPEG7Click(TObject *Sender);
     void __fastcall M_View_PBCoreClick(TObject *Sender);
+    void __fastcall M_View_EBUCore_1_4Click(TObject *Sender);
     void __fastcall M_View_XMLClick(TObject *Sender);
     void __fastcall M_DigimetricsClick(TObject *Sender);
     void __fastcall M_View_reVTMDClick(TObject *Sender);
