@@ -1,21 +1,8 @@
-// GUI_Main_Tree - VCL GUI for MediaInfo
-// Copyright (C) 2002-2012 MediaArea.net SARL, Info@MediaArea.net
-//
-// This program is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Library General Public License as published by
-// the Free Software Foundation, either version 2 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public License
-// along with this program. If not, see <http://www.gnu.org/licenses/>.
-//
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+/*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ *
+ *  Use of this source code is governed by a BSD-style license that can
+ *  be found in the License.html file in the root of the source tree.
+ */
 
 //---------------------------------------------------------------------------
 #include <vcl.h>
@@ -91,8 +78,6 @@ void GUI_Main_Tree::GUI_Resize()
 //---------------------------------------------------------------------------
 void GUI_Main_Tree::Item_Show(TTreeNode *Item)
 {
-    TTreeNode* ItemID;
-    size_t Level=0;
     size_t Pos1=TextPos[Item];
     size_t Pos2=0;
     size_t LevelBase;
@@ -116,18 +101,18 @@ void GUI_Main_Tree::Item_Show(TTreeNode *Item)
         #else
             #define SIZE 0
         #endif
-        Level=Text.find_first_not_of(__T(' '), Pos1+9)-(Pos1+9);
+        size_t Level=Text.find_first_not_of(__T(' '), Pos1+9)-(Pos1+9);
         if (Level==LevelBase+1)
         {
             //Showing line
             MediaInfoLib::String Line=Text.substr(Pos1, Pos2-Pos1-SIZE);
-            if (Line.size()>10 & Line[9]==__T(' '))
+            if (Line.size()>10 && Line[9]==__T(' '))
             {
                 Line.erase(9, Level);
             }
             if (!Line.empty())
             {
-                ItemID==VCL->Items->Add(Item, Line.c_str());
+                TTreeNode* ItemID==VCL->Items->Add(Item, Line.c_str());
                 TextPos[ItemID]=Pos1;
             }
         }
