@@ -1,21 +1,8 @@
-// GUI_Main_Text - WxWidgets GUI for MediaInfo
-// Copyright (C) 2002-2012 MediaArea.net SARL, Info@MediaArea.net
-//
-// This program is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Library General Public License as published by
-// the Free Software Foundation, either version 2 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public License
-// along with this program. If not, see <http://www.gnu.org/licenses/>.
-//
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+/*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ *
+ *  Use of this source code is governed by a BSD-style license that can
+ *  be found in the License.html file in the root of the source tree.
+ */
 
 //---------------------------------------------------------------------------
 #include "wx/wxprec.h"
@@ -43,6 +30,9 @@ GUI_Main_Text::GUI_Main_Text(Core* _C, wxWindow* parent)
     Font.SetFamily(wxFONTFAMILY_MODERN);
     wxTextAttr Attr;
     Attr.SetFont(Font);
+    #if wxCHECK_VERSION(2, 9, 0)
+        Attr.SetFontSize(8);
+    #endif
     SetDefaultStyle(Attr);
 
     //Drag and Drop
