@@ -1,21 +1,8 @@
-// GUI_Main_Tree - WxWidgets GUI for MediaInfo
-// Copyright (C) 2002-2012 MediaArea.net SARL, Info@MediaArea.net
-//
-// This program is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Library General Public License as published by
-// the Free Software Foundation, either version 2 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public License
-// along with this program. If not, see <http://www.gnu.org/licenses/>.
-//
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+/*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ *
+ *  Use of this source code is governed by a BSD-style license that can
+ *  be found in the License.html file in the root of the source tree.
+ */
 
 //---------------------------------------------------------------------------
 #include "wx/wxprec.h"
@@ -94,6 +81,8 @@ void GUI_Main_Tree::GUI_Resize()
 //---------------------------------------------------------------------------
 void GUI_Main_Tree::Item_Show(const wxTreeItemId &Item)
 {
+    DeleteChildren(Item);
+    
     wxTreeItemId ItemID;
     //wxFont Font(8, wxFONTFAMILY_MODERN, wxFONTSTYLE_NORMAL, wxFONTWEIGHT_NORMAL);
     //wxFont Font(10, wxFONTFAMILY_MODERN, wxFONTSTYLE_NORMAL, wxFONTWEIGHT_NORMAL);
@@ -156,6 +145,6 @@ void GUI_Main_Tree::OnItemExpanding(wxTreeEvent& event)
 
 void GUI_Main_Tree::OnItemCollapsing(wxTreeEvent& event)
 {
-    CollapseAndReset(event.GetItem());
-    SetItemHasChildren(event.GetItem());
+    //CollapseAndReset(event.GetItem());
+    //SetItemHasChildren(event.GetItem());
 }
